2022-09-23 Version: 1.0.20
- Add new API DescribeGrantRulesToResource .
- Update DescribeGrantRulesToCen support MaxResult and nextToken .
- Update ListTransitRouterPrefixlistAssociation return TransitRouterId and TransitRouterTableId .

2022-08-26 Version: 1.0.19
- Update param NextHopType visibility for DeleteTransitRouterPrefixListAssociation .

2022-08-26 Version: 1.0.18
- Add AvailableZones for ListTransitRouterAvailableResource.

2022-04-27 Version: 1.0.17
- update to latest.

2022-04-15 Version: 1.0.16
- Support Multicast.
- RouteMap Support sub-table.

2022-03-10 Version: 1.0.15
- Modify the input parameter Action of CreateCen to be required.

2022-01-11 Version: 1.0.14
- Support  DeleteTransitRouter API.

2021-12-21 Version: 1.0.13
- Support Darabonba API.

2021-05-06 Version: 1.0.2
- Generated python 2017-09-12 for Cbn.

2021-04-23 Version: 1.0.1
- Generated python 2017-09-12 for Cbn.

2020-12-29 Version: 1.0.0
- AMP Version Change.

